@@ -16,7 +16,7 @@ struct TestStruct {
         field_b: 0x01,
     }),
 
-    #[should_panic(expected = r#"Assertion("field field_b failed assertion: field_b == * field_a")"#)]
+    #[should_panic(expected = r#"Assertion("TestStruct.field_b field failed assertion: field_b == * field_a")"#)]
     case(&hex!("0102"), TestStruct::default())
 )]
 fn test_assert_eq_read(input: &[u8], expected: TestStruct) {
@@ -30,7 +30,7 @@ fn test_assert_eq_read(input: &[u8], expected: TestStruct) {
         field_b: 0x01,
     }, hex!("0101").to_vec()),
 
-    #[should_panic(expected = r#"Assertion("field field_b failed assertion: field_b == * field_a")"#)]
+    #[should_panic(expected = r#"Assertion("TestStruct.field_b field failed assertion: field_b == * field_a")"#)]
     case(TestStruct {
         field_a: 0x01,
         field_b: 0x02,
